pub struct CowSoundVariant {
pub key: Identifier,
pub ambient_sound: SoundEventRef,
pub death_sound: SoundEventRef,
pub hurt_sound: SoundEventRef,
pub step_sound: SoundEventRef,
}Expand description
Represents a set of sounds for a cow variant from a data pack JSON file.
Fields
key: Identifierambient_sound: SoundEventRefdeath_sound: SoundEventRefhurt_sound: SoundEventRefstep_sound: SoundEventRefTrait Implementations
Sourceimpl Debug for CowSoundVariant
impl Debug for CowSoundVariant
impl Eq for CowSoundVariant
Sourceimpl PartialEq for CowSoundVariant
impl PartialEq for CowSoundVariant
Sourceimpl RegistryEntry for CowSoundVariant
impl RegistryEntry for CowSoundVariant
Sourceimpl RegistryReferenceEntry for CowSoundVariant
impl RegistryReferenceEntry for CowSoundVariant
Sourceconst REGISTRY_NAME: &'static str = "cow sound variant"
const REGISTRY_NAME: &'static str = "cow sound variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &CowSoundVariant
impl ToNbtTag for &CowSoundVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>